decorrelation
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

[Documentation](https://kanglcn.github.io/decorrelation)

> InSAR postprocessing tool

## Install

With conda:

``` bash
conda install -c conda-forge decorrelation
```

With pip:

``` bash
pip install decorrelation
```

In development mode:

``` bash
git clone git@github.com:kanglcn/decorrelation.git ./decorrelation
cd ./decorrelation
pip install -e '.[dev]'
```

## How to use

``` python
import decorrelation as dc
```

Please refer to the
[Documentation](https://kanglcn.github.io/decorrelation) for detailed
usage.

## Contact us

- Most discussion happens on
  [GitHub](https://github.com/kanglcn/decorrelation). Feel free to [open
  an issue](https://github.com/kanglcn/decorrelation/issues/new) or
  comment on any open issue or pull request.
- use github
  [discussions](https://github.com/kanglcn/decorrelation/discussions) to
  ask questions or leave comments.

## Contribution

- Pull requests are welcomed! Before making a pull request, please open
  an issue to talk about it.
- We have notice many excellent open-source packages are rarely paid
  attention to due to lake of documentation. The package is developed
  with the [nbdev](https://nbdev.fast.ai/), a notebook-driven
  development platform. Developers only needs to simply write notebooks
  with lightweight markup and get high-quality documentation, tests,
  continuous integration, and packaging automatically.
